@@ -28,7 +28,6 @@ echo "Downloading and extracting to $SDCARD..."
 export INSTPATH="/home/user/img-install"
 export TARPATH="$SDCARD"
 export DLURL="http://qole.org/files"
-export BZ2CMD1="bzip2 -dc "
 #This doesn't work:
 #export BZ2CMD1="bzcat"
 #export BZ2CMD2="| tar xf -"
@@ -36,11 +35,12 @@ export GZCMD1="tar -xzf"
 
 export EXTPATH1=$TARPATH
 export PKGNAME1="EASY DEBIAN IMAGE FILE"
-export BIGTAR1="debian-squeeze-m5-img.bz2"
-export BIGIMG1="debian-squeeze-m5.img.ext2"
+export BIGTAR1="debian-m5-v2.img.ext2.bz2"
+export BIGIMG1="debian-m5-v2.img.ext2"
+export BZ2CMD1="bzip2 -dc "
 export BZ2CMD2=" > $TARPATH/$BIGIMG1"
 export TARCMD1="$BZ2CMD1 $TARPATH/$BIGTAR1 $BZ2CMD2"
-export MD51="f769bb84c99f75821bdfa37e5ea34e86"
+export MD51="1c02d35d6453fd35390ae025bd930ba2"
 export EXTCMD1=""
 
 #Set SKIPPKG2=1 to skip the second package.
@@ -100,9 +100,14 @@ do
 
      cd $EXTPATH1
      echo Extracting the image file. This will take some time.
+
      TARERR=`$TARCMD1 2>&1`
+     # TARERR="unspecified bzip2 error"
+     # echo $TARCMD1
+     $BZ2CMD1 $TARPATH/$BIGTAR1 
+     # > $TARPATH/$BIGIMG1
      if [ "$?" = 0 ] ; then
-	 rm -rf $TARPATH/$BIGTAR1
+	 # rm -rf $TARPATH/$BIGTAR1
          $EXTCMD1
          export MSG1=`printf "CONGRATULATIONS!\n\nAll has gone well!\n\nSuccess installing $PKGNAME1 package!"`
          gxmessage -center -alignbuttons right -buttons GTK_STOCK_OK:0 -geometry 640x250 -title "SUCCESS!" "$MSG1"
